package com.yanzhu.manage.mapper;

import java.util.List;

import com.yanzhu.manage.domain.ProDept;
import com.yanzhu.manage.domain.ProProjectInfo;

/**
 * 项目信息Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface ProProjectInfoMapper 
{
    /**
     * 查询项目信息
     * 
     * @param id 项目信息主键
     * @return 项目信息
     */
    public ProProjectInfo selectProProjectInfoById(Long id);

    /**
     * 查询项目信息列表
     * 
     * @param proProjectInfo 项目信息
     * @return 项目信息集合
     */
    public List<ProProjectInfo> selectProProjectInfoList(ProProjectInfo proProjectInfo);

    /**
     * 新增项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    public int insertProProjectInfo(ProProjectInfo proProjectInfo);

    /**
     * 修改项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    public int updateProProjectInfo(ProProjectInfo proProjectInfo);

    /**
     * 删除项目信息
     * 
     * @param id 项目信息主键
     * @return 结果
     */
    public int deleteProProjectInfoById(Long id);

    /**
     * 批量删除项目信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProProjectInfoByIds(Long[] ids);

    /**
     * 在单位层级新增项目
     * @param proDept
     * @return
     */
    public int insertDept(ProDept proDept);

    /**
     * 在单位层级新增项目
     * @param proDept
     * @return
     */
    public int updateDept(ProDept proDept);
}
